//Source file: APIUnavailReason.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * The reason why the API is unavailable.
 * 
 */
public final class APIUnavailReason implements java.io.Serializable {

    private int _value;
    private static int _size = 6;
    private static APIUnavailReason[] _array = new APIUnavailReason[_size];

    /**
     * Undefined. 
     */
    public static final int _API_UNAVAILABLE_UNDEFINED =  0;
    /**
     * Undefined. 
     */
    public static final APIUnavailReason API_UNAVAILABLE_UNDEFINED = new APIUnavailReason(_API_UNAVAILABLE_UNDEFINED);

    /**
     * The local API software or hardware has failed.
     */
    public static final int _API_UNAVAILABLE_LOCAL_FAILURE =  1;
    /**
     * The local API software or hardware has failed.
     */
    public static final APIUnavailReason API_UNAVAILABLE_LOCAL_FAILURE = new APIUnavailReason(_API_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * The gateway API software or hardware has failed.
     */
    public static final int _API_UNAVAILABLE_GATEWAY_FAILURE =  2;
    /**
     * The gateway API software or hardware has failed.
     */
    public static final APIUnavailReason API_UNAVAILABLE_GATEWAY_FAILURE = new APIUnavailReason(_API_UNAVAILABLE_GATEWAY_FAILURE);

    /**
     * The framework is fully overloaded.
     */
    public static final int _API_UNAVAILABLE_OVERLOADED =  3;
    /**
     * The framework is fully overloaded.
     */
    public static final APIUnavailReason API_UNAVAILABLE_OVERLOADED = new APIUnavailReason(_API_UNAVAILABLE_OVERLOADED);

    /**
     * The framework has closed itself.
     */
    public static final int _API_UNAVAILABLE_CLOSED =  4;
    /**
     * The framework has closed itself.
     */
    public static final APIUnavailReason API_UNAVAILABLE_CLOSED = new APIUnavailReason(_API_UNAVAILABLE_CLOSED);

    /**
     * The protocol used on the client - gateway link has failed.
     */
    public static final int _API_UNAVAILABLE_PROTOCOL_FAILURE =  5;
    /**
     * The protocol used on the client - gateway link has failed.
     */
    public static final APIUnavailReason API_UNAVAILABLE_PROTOCOL_FAILURE = new APIUnavailReason(_API_UNAVAILABLE_PROTOCOL_FAILURE);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the APIUnavailReason object
     */
    public String toString() {
        switch (_value) {
            case _API_UNAVAILABLE_UNDEFINED:
                return "API_UNAVAILABLE_UNDEFINED";
            case _API_UNAVAILABLE_LOCAL_FAILURE:
                return "API_UNAVAILABLE_LOCAL_FAILURE";
            case _API_UNAVAILABLE_GATEWAY_FAILURE:
                return "API_UNAVAILABLE_GATEWAY_FAILURE";
            case _API_UNAVAILABLE_OVERLOADED:
                return "API_UNAVAILABLE_OVERLOADED";
            case _API_UNAVAILABLE_CLOSED:
                return "API_UNAVAILABLE_CLOSED";
            case _API_UNAVAILABLE_PROTOCOL_FAILURE:
                return "API_UNAVAILABLE_PROTOCOL_FAILURE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 6
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static APIUnavailReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private APIUnavailReason(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) return false;
        if(!(o instanceof APIUnavailReason)) {
        return false;
        } else {
            APIUnavailReason aPIUnavailReason = ( APIUnavailReason)o; 
            if(!(this.getValue() == getValue())) {
                return false;
            }
        }
    
    if (this.hashCode() != o.hashCode()) {
    return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // APIUnavailReason

