//Source file: LoadLevel.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * The load level values.
 * 
 */
public final class LoadLevel implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static LoadLevel[] _array = new LoadLevel[_size];

    /**
     * Normal load
     */
    public static final int _LOAD_LEVEL_NORMAL =  0;
    /**
     * Normal load
     */
    public static final LoadLevel LOAD_LEVEL_NORMAL = new LoadLevel(_LOAD_LEVEL_NORMAL);

    /**
     * Overload
     */
    public static final int _LOAD_LEVEL_OVERLOAD =  1;
    /**
     * Overload
     */
    public static final LoadLevel LOAD_LEVEL_OVERLOAD = new LoadLevel(_LOAD_LEVEL_OVERLOAD);

    /**
     * Severe overload
     */
    public static final int _LOAD_LEVEL_SEVERE_OVERLOAD =  2;
    /**
     * Severe overload
     */
    public static final LoadLevel LOAD_LEVEL_SEVERE_OVERLOAD = new LoadLevel(_LOAD_LEVEL_SEVERE_OVERLOAD);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadLevel object
     */
    public String toString() {
        switch (_value) {
            case _LOAD_LEVEL_NORMAL:
                return "LOAD_LEVEL_NORMAL";
            case _LOAD_LEVEL_OVERLOAD:
                return "LOAD_LEVEL_OVERLOAD";
            case _LOAD_LEVEL_SEVERE_OVERLOAD:
                return "LOAD_LEVEL_SEVERE_OVERLOAD";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadLevel getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadLevel(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) return false;
        if(!(o instanceof LoadLevel)) {
        return false;
        } else {
            LoadLevel loadLevel = ( LoadLevel)o; 
            if(!(this.getValue() == getValue())) {
                return false;
            }
        }
    
    if (this.hashCode() != o.hashCode()) {
    return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadLevel

