//Source file: LoadStatisticEntityType.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * Defines the type of entity (that is, service, application or framework) supplying load statistics.
 * 
 */
public final class LoadStatisticEntityType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static LoadStatisticEntityType[] _array = new LoadStatisticEntityType[_size];

    /**
     * Framework-type load statistics
     */
    public static final int _LOAD_STATISTICS_FW_TYPE =  0;
    /**
     * Framework-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_FW_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_FW_TYPE);

    /**
     * Service-type load statistics
     */
    public static final int _LOAD_STATISTICS_SVC_TYPE =  1;
    /**
     * Service-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_SVC_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_SVC_TYPE);

    /**
     * Application-type load statistics
     */
    public static final int _LOAD_STATISTICS_APP_TYPE =  2;
    /**
     * Application-type load statistics
     */
    public static final LoadStatisticEntityType LOAD_STATISTICS_APP_TYPE = new LoadStatisticEntityType(_LOAD_STATISTICS_APP_TYPE);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the LoadStatisticEntityType object
     */
    public String toString() {
        switch (_value) {
            case _LOAD_STATISTICS_FW_TYPE:
                return "LOAD_STATISTICS_FW_TYPE";
            case _LOAD_STATISTICS_SVC_TYPE:
                return "LOAD_STATISTICS_SVC_TYPE";
            case _LOAD_STATISTICS_APP_TYPE:
                return "LOAD_STATISTICS_APP_TYPE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static LoadStatisticEntityType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private LoadStatisticEntityType(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) return false;
        if(!(o instanceof LoadStatisticEntityType)) {
        return false;
        } else {
            LoadStatisticEntityType loadStatisticEntityType = ( LoadStatisticEntityType)o; 
            if(!(this.getValue() == getValue())) {
                return false;
            }
        }
    
    if (this.hashCode() != o.hashCode()) {
    return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // LoadStatisticEntityType

