//Source file: ServiceTypePropertyMode.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * This type defines SCF property modes.
 * 
 */
public final class ServiceTypePropertyMode implements java.io.Serializable {

    private int _value;
    private static int _size = 4;
    private static ServiceTypePropertyMode[] _array = new ServiceTypePropertyMode[_size];

    /**
     * The value of the corresponding SCF property type may optionally be provided
     */
    public static final int _NORMAL =  0;
    /**
     * The value of the corresponding SCF property type may optionally be provided
     */
    public static final ServiceTypePropertyMode NORMAL = new ServiceTypePropertyMode(_NORMAL);

    /**
     * The value of the corresponding SCF property type shall be provided at service registration time
     */
    public static final int _MANDATORY =  1;
    /**
     * The value of the corresponding SCF property type shall be provided at service registration time
     */
    public static final ServiceTypePropertyMode MANDATORY = new ServiceTypePropertyMode(_MANDATORY);

    /**
     * The value of the corresponding SCF property type is optional, but once given a value it can not be modified/restricted by a service level agreement
     */
    public static final int __READONLY =  2;
    /**
     * The value of the corresponding SCF property type is optional, but once given a value it can not be modified/restricted by a service level agreement
     */
    public static final ServiceTypePropertyMode _READONLY = new ServiceTypePropertyMode(__READONLY);

    /**
     * The value of the corresponding SCF property type shall be provided but can not subsequently be modified/restricted by a service level agreement
     */
    public static final int _MANDATORY_READONLY =  3;
    /**
     * The value of the corresponding SCF property type shall be provided but can not subsequently be modified/restricted by a service level agreement
     */
    public static final ServiceTypePropertyMode MANDATORY_READONLY = new ServiceTypePropertyMode(_MANDATORY_READONLY);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the ServiceTypePropertyMode object
     */
    public String toString() {
        switch (_value) {
            case _NORMAL:
                return "NORMAL";
            case _MANDATORY:
                return "MANDATORY";
            case __READONLY:
                return "_READONLY";
            case _MANDATORY_READONLY:
                return "MANDATORY_READONLY";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 4
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static ServiceTypePropertyMode getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private ServiceTypePropertyMode(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) return false;
        if(!(o instanceof ServiceTypePropertyMode)) {
        return false;
        } else {
            ServiceTypePropertyMode serviceTypePropertyMode = ( ServiceTypePropertyMode)o; 
            if(!(this.getValue() == getValue())) {
                return false;
            }
        }
    
    if (this.hashCode() != o.hashCode()) {
    return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // ServiceTypePropertyMode

