//Source file: SubjectType.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * Defines the subject of a query/notification request/result. 
 *
 * 
 */
public final class SubjectType implements java.io.Serializable {

    private int _value;
    private static int _size = 3;
    private static SubjectType[] _array = new SubjectType[_size];

    /**
     * The subject is neither the framework nor the client application
     */
    public static final int _SUBJECT_UNDEFINED =  0;
    /**
     * The subject is neither the framework nor the client application
     */
    public static final SubjectType SUBJECT_UNDEFINED = new SubjectType(_SUBJECT_UNDEFINED);

    /**
     * The subject is the client application
     */
    public static final int _SUBJECT_CLIENT_APP =  1;
    /**
     * The subject is the client application
     */
    public static final SubjectType SUBJECT_CLIENT_APP = new SubjectType(_SUBJECT_CLIENT_APP);

    /**
     * The subject is the framework
     */
    public static final int _SUBJECT_FW =  2;
    /**
     * The subject is the framework
     */
    public static final SubjectType SUBJECT_FW = new SubjectType(_SUBJECT_FW);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the SubjectType object
     */
    public String toString() {
        switch (_value) {
            case _SUBJECT_UNDEFINED:
                return "SUBJECT_UNDEFINED";
            case _SUBJECT_CLIENT_APP:
                return "SUBJECT_CLIENT_APP";
            case _SUBJECT_FW:
                return "SUBJECT_FW";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 3
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SubjectType getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private SubjectType(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) return false;
        if(!(o instanceof SubjectType)) {
        return false;
        } else {
            SubjectType subjectType = ( SubjectType)o; 
            if(!(this.getValue() == getValue())) {
                return false;
            }
        }
    
    if (this.hashCode() != o.hashCode()) {
    return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SubjectType

