//Source file: SvcAvailStatusReason.java
//Date: July 2003
//Framework Data Types for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw;

/**
 * Defines the reason why a SCF is unavailable
 *
 * 
 */
public final class SvcAvailStatusReason implements java.io.Serializable {

    private int _value;
    private static int _size = 8;
    private static SvcAvailStatusReason[] _array = new SvcAvailStatusReason[_size];

    /**
     * Undefined
     */
    public static final int _SVC_UNAVAILABLE_UNDEFINED =  0;
    /**
     * Undefined
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_UNDEFINED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_UNDEFINED);

    /**
     * The local API software or hardware has failed
     */
    public static final int _SVC_UNAVAILABLE_LOCAL_FAILURE =  1;
    /**
     * The local API software or hardware has failed
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_LOCAL_FAILURE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_LOCAL_FAILURE);

    /**
     * The gateway API software or hardware has failed
     */
    public static final int _SVC_UNAVAILABLE_GATEWAY_FAILURE =  2;
    /**
     * The gateway API software or hardware has failed
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_GATEWAY_FAILURE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_GATEWAY_FAILURE);

    /**
     * The SCF is fully overloaded
     */
    public static final int _SVC_UNAVAILABLE_OVERLOADED =  3;
    /**
     * The SCF is fully overloaded
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_OVERLOADED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_OVERLOADED);

    /**
     * The SCF has closed itself (for example, to protect from fraud or malicious attack)
     */
    public static final int _SVC_UNAVAILABLE_CLOSED =  4;
    /**
     * The SCF has closed itself (for example, to protect from fraud or malicious attack)
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_CLOSED = new SvcAvailStatusReason(_SVC_UNAVAILABLE_CLOSED);

    /**
     * The framework has detected that the service has failed, for example, non-response from an activity test, failure to return heartbeats
     */
    public static final int _SVC_UNAVAILABLE_NO_RESPONSE =  5;
    /**
     * The framework has detected that the service has failed, for example, non-response from an activity test, failure to return heartbeats
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_NO_RESPONSE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_NO_RESPONSE);

    /**
     * The Service is unavailable due to software upgrade or other similar maintenance. Normally a temporary problem 
     */
    public static final int _SVC_UNAVAILABLE_SW_UPGRADE =  6;
    /**
     * The Service is unavailable due to software upgrade or other similar maintenance. Normally a temporary problem 
     */
    public static final SvcAvailStatusReason SVC_UNAVAILABLE_SW_UPGRADE = new SvcAvailStatusReason(_SVC_UNAVAILABLE_SW_UPGRADE);

    /**
     * The Service has become available again
     */
    public static final int _SVC_AVAILABLE =  7;
    /**
     * The Service has become available again
     */
    public static final SvcAvailStatusReason SVC_AVAILABLE = new SvcAvailStatusReason(_SVC_AVAILABLE);


    /**
     * Number representing enum type
     *
     * @return int number representing type of object, this is defined within the class
     */
    public int getValue() {
        return _value;
    }

    /**
     * toString method, overrides the toString() method in class java.lang.Object
     *
     * @return String  The stringified version of the SvcAvailStatusReason object
     */
    public String toString() {
        switch (_value) {
            case _SVC_UNAVAILABLE_UNDEFINED:
                return "SVC_UNAVAILABLE_UNDEFINED";
            case _SVC_UNAVAILABLE_LOCAL_FAILURE:
                return "SVC_UNAVAILABLE_LOCAL_FAILURE";
            case _SVC_UNAVAILABLE_GATEWAY_FAILURE:
                return "SVC_UNAVAILABLE_GATEWAY_FAILURE";
            case _SVC_UNAVAILABLE_OVERLOADED:
                return "SVC_UNAVAILABLE_OVERLOADED";
            case _SVC_UNAVAILABLE_CLOSED:
                return "SVC_UNAVAILABLE_CLOSED";
            case _SVC_UNAVAILABLE_NO_RESPONSE:
                return "SVC_UNAVAILABLE_NO_RESPONSE";
            case _SVC_UNAVAILABLE_SW_UPGRADE:
                return "SVC_UNAVAILABLE_SW_UPGRADE";
            case _SVC_AVAILABLE:
                return "SVC_AVAILABLE";
            default:
                return "ERROR";
        }
    }

    /**
     * Accepts values in the range of 0 to 8
     *
     * @param value number representing type of object, this is defined within the class
     * @throws org.csapi.jr.se.InvalidEnumValueException thrown if invalid value is passed into method
     */
    public static SvcAvailStatusReason getObject(int value) throws org.csapi.jr.se.InvalidEnumValueException {
        if(value >= 0 && value < _size) {
            return _array[value];
        } else {
            throw new org.csapi.jr.se.InvalidEnumValueException();
        }
    }

    /**
     * Private constructor used internally to construct static objects 
     */
    private SvcAvailStatusReason(int value) {
        this._value = value;
        this._array[this._value] = this;
    }

    /**
     * Indicates whether some other object is 'equal to' this one.
     */
    public boolean equals(Object o) {
        if (o == null) { 
            return false;
        }

        if(!(o instanceof SvcAvailStatusReason)) {
            return false;
        }

        SvcAvailStatusReason svcAvailStatusReason = ( SvcAvailStatusReason)o; 
        if(!(this.getValue() == svcAvailStatusReason.getValue())) {
            return false;
        }
    
        if (this.hashCode() != svcAvailStatusReason.hashCode()) {
            return false;
        }
        return true;
    }

    /**
     * Returns a hashcode value for the object.
     */
    public int hashCode() {
        return 1;
    }

} // SvcAvailStatusReason

