//Source file: Access.java
//Date: July 2003
//Framework Access Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_access.trust_and_security;

/**
 * This interface shall be implemented by a Framework.  As a minimum requirement the obtainInterface() and obtainInterfaceWithCallback(), selectSigningAlgorithm() and terminateAccess() methods shall be implemented.  
 *
 * 
 * 
 */
public interface Access extends org.csapi.jr.se.CsapiInterface{

    /**
     * This method is used to obtain other framework interfaces. The client uses this method to obtain interface references to other framework interfaces. (The obtainInterfaceWithCallback method should be used if the client is required to supply a callback interface to the framework.)
Returns <fwInterface> : This is the reference to the interface requested.
     *     @param interfaceName The name of the framework interface to which a reference to the interface is requested. If the interfaceName is invalid, the framework returns an error code (P_INVALID_INTERFACE_NAME).

     */
    org.csapi.jr.se.CsapiInterface  obtainInterface(String interfaceName)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.InvalidInterfaceNameException,org.csapi.jr.se.PlatformException;

    /**
     * This method is used to obtain other framework interfaces. The client uses this method to obtain interface references to other framework interfaces, when it is required to supply a callback interface to the framework. (The obtainInterface method should be used when no callback interface needs to be supplied.)
Returns <fwInterface> : This is the reference to the interface requested.
     *     @param interfaceName The name of the framework interface to which a reference to the interface is requested. If the interfaceName is invalid, the framework returns an error code (P_INVALID_INTERFACE_NAME).
    @param clientInterface This is the reference to the client interface, which is used for callbacks. If a client interface is not needed, then this method should not be used. (The obtainInterface method should be used when no callback interface needs to be supplied.)  If the interface reference is not of the correct type, the framework returns an error code (P_INVALID_INTERFACE_TYPE).

     */
    org.csapi.jr.se.CsapiInterface  obtainInterfaceWithCallback(String interfaceName, org.csapi.jr.se.CsapiInterface clientInterface)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.InvalidInterfaceNameException,org.csapi.jr.se.InvalidInterfaceTypeException,org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is replaced with terminateAccess.  The endAccess operation is used by the client to request that its access session with the framework is ended.  After it is invoked, the client will no longer be authenticated with the framework. The client will not be able to use the references to any of the framework interfaces gained during the access session. Any calls to these interfaces will fail.
     *     @param endAccessProperties  This is a list of properties that can be used to tell the framework the actions to perform when ending the access session (e.g. existing service sessions may be stopped, or left running).  If a property is not recognised by the framework, an error code (P_INVALID_PROPERTY) is returned. 

     */
    void  endAccess(org.csapi.jr.se.fw.Property[] endAccessProperties)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidPropertyException,org.csapi.jr.se.PlatformException;

    /**
     * The client uses this method to obtain the names of all interfaces supported by the framework.  It can then obtain the interfaces it wishes to use using either obtainInterface() or obtainInterfaceWithCallback().
Returns <frameworkInterfaces> : The frameworkInterfaces parameter contains a list of interfaces that the framework makes available.
     * 
     */
    String[]  listInterfaces()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is replaced with relinquishInterface.  The client uses this method to release a framework interface that was obtained during this access session. 
     *     @param interfaceName This is the name of the framework interface which is being released. If the interfaceName is invalid, the framework throws the P_INVALID_INTERFACE_NAME exception.  If the interface has not been given to the client during this access session, then the P_TASK_REFUSED exception will be thrown.

     */
    void  releaseInterface(String interfaceName)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.InvalidInterfaceNameException,org.csapi.jr.se.PlatformException;

    /**
     * The client uses this method to inform the Framework of the different signing  algorithms it supports for use in all cases where digital signatures are required.  The Framework will select one of the suggested algorithms.   This method shall be the first method invoked by the client on IpAccess.  The algorithm chosen as a result of the response to this method remains valid for an instance of IpAccess and until this method is re-invoked by the client. If an algorithm that is acceptable to the framework within the capability of the client cannot be found, the framework  throws the P_NO_ACCEPTABLE_SIGNING_ALGORITHM exception.   
Returns: selectedAlgorithm.  This is the signing algorithm chosen by the Framework.  The chosen algorithm shall be taken from the list proposed by the Client.
     *     @param signingAlgorithmCaps The list of signing algorithms supported by the client.

     */
    String  selectSigningAlgorithm(String signingAlgorithmCaps)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.NoAcceptableSigningAlgorithmException,org.csapi.jr.se.PlatformException;

    /**
     * The terminateAccess method is used by the client to request that its access session with the framework is ended.  After it is invoked, the client will no longer be authenticated with the framework. The client will not be able to use the references to any of the framework interfaces gained during the access session. Any calls to these interfaces will fail. Also, all remaining service instances created by the framework either directly in this access session or on behalf of the client during this access session shall be terminated.
     *     @param terminationText This is the termination text describes the reason for the termination of the access session.
    @param digitalSignature This contains a CMS (Cryptographic Message Syntax) object (as defined in RFC 2630) with content type Signed-data. The signature is calculated and created as per section 5 of RFC 2630. The content is made of the termination text. The "external signature" construct shall not be used (i.e. the eContent field in the EncapsulatedContentInfo field shall be present and contain the termination text string). The signing-time attribute, as defined in section 11.3 of RFC 2630, shall also be used to provide replay prevention. The client uses this to confirm its identity to the framework. The framework can check that the terminationText has been signed by the client. If a match is made, the access session is terminated, otherwise the P_INVALID_SIGNATURE exception will be thrown.

     */
    void  terminateAccess(String terminationText, byte[] digitalSignature)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidSignatureException,org.csapi.jr.se.PlatformException;

    /**
     * The client uses this method to release an instance of a framework interface that was obtained during this access session.  
     *     @param interfaceName This is the name of the framework interface which is being released. If the interfaceName is invalid, the framework throws the P_INVALID_INTERFACE_NAME exception.  If the interface has not been given to the client during this access session, then the P_TASK_REFUSED exception will be thrown.
    @param terminationText This is the termination text describes the reason for the release of the interface.  This text is required simply because the digitalSignature parameter requires a terminationText to sign.
    @param digitalSignature This contains a CMS (Cryptographic Message Syntax) object (as defined in RFC 2630) with content type Signed-data. The signature is calculated and created as per section 5 of RFC 2630. The content is made of the termination text. The "external signature" construct shall not be used (i.e. the eContent field in the EncapsulatedContentInfo field shall be present and contain the termination text string). The signing-time attribute, as defined in section 11.3 of RFC 2630, shall also be used to provide replay prevention. The client uses this to confirm its identity to the framework. The framework can check that the terminationText has been signed by the client. If a match is made, the interface is released, otherwise the P_INVALID_SIGNATURE exception will be thrown.

     */
    void  relinquishInterface(String interfaceName, String terminationText, byte[] digitalSignature)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidSignatureException,org.csapi.jr.se.InvalidInterfaceNameException,org.csapi.jr.se.PlatformException;


} // Access

