//Source file: ServiceDiscovery.java
//Date: July 2003
//Framework to Application Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_application.discovery;

/**
 * The service discovery interface, shown below, consists of four methods. Before a service can be discovered, the enterprise operator (or the client applications) must know what "types" of services are supported by the Framework and what service "properties" are applicable to each service type. The listServiceType() method returns a list of all "service types" that are currently supported by the framework and the "describeServiceType()" returns a description of each service type. The description of service type includes the "service-specific properties" that are applicable to each service type. Then the enterprise operator (or the client applications) can discover a specific set of registered services that both belong to a given type and possess the desired "property values", by using the "discoverService() method.  Once the enterprise operator finds out the desired set of services supported by the framework, it subscribes to (a sub-set of) these services using the Subscription Interfaces. The enterprise operator (or the client applications in its domain) can find out the set of services available to it (i.e., the service that it can use) by invoking "listSubscribedServices()".  The service discovery APIs are invoked by the enterprise operators or client applications. They are described below.				This interface shall be implemented by a Framework with as a minimum requirement the listServiceTypes(), describeServiceType() and discoverService() methods.
 *
 */
public interface ServiceDiscovery extends org.csapi.jr.se.CsapiInterface{

    /**
     * This operation returns the names of all service types that are in the repository.<br>
     * The details of the service types can then be obtained using the describeServiceType() method.<br>
     * Returns <listTypes> : The names of the requested service types.
     * 
     */
    String[]  listServiceTypes()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.PlatformException;

    /**
     * This operation lets the caller obtain the details for a particular service type.<br>
     * Returns <serviceTypeDescription> : The description of the specified service type. The description provides information about:<br>
     * - the service properties associated with this service type: i.e. a list of service property {name, mode and type} tuples,<br>
     * - the names of the super types of this service type, and<br>
     * - whether the service type is currently available or unavailable.
     *     @param name The name of the service type to be described.<br>
     * If the "name" is malformed, then the P_ILLEGAL_SERVICE_TYPE exception is raised. <br>
     * If the "name" does not exist in the repository, then the P_UNKNOWN_SERVICE_TYPE exception is raised.
     */
    org.csapi.jr.se.fw.ServiceTypeDescription  describeServiceType(String name)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.IllegalServiceTypeException,org.csapi.jr.se.fw.UnknownServiceTypeException,org.csapi.jr.se.PlatformException;

    /**
     * The discoverService operation is the means by which a client application is able to obtain the service IDs of the services that meet its requirements.<br>
     * The client application passes in a list of desired service properties to describe the service it is looking for, in the form of attribute/value pairs for the service properties. 
     * The client application also specifies the maximum number of matched responses it is willing to accept. The framework must not return more matches than the specified maximum, but it is up to the discretion of the Framework implementation to choose to return less than the specified maximum.<br> 
     * The discoverService() operation returns a serviceID/Property pair list for those services that match the desired service property list that the client application provided.  The service properties returned will form a complete view of what the client application will be able to do with the service, as per the service level agreement.  <br>
     * If the framework supports service subscription, the service level agreement will be encapsulated in the subscription properties contained in the contract/profile for the client application, which will be a restriction of the registered properties.<br>
     * Returns <serviceList> : This parameter gives a list of matching services. Each service is characterised by its service ID and a list of service properties {name and value list} associated with the service.
     *     @param serviceTypeName The "serviceTypeName" parameter conveys the required service type. It is key to the central purpose of "service trading". It is the basis for type safe interactions between the service exporters (via registerService) and service importers (via discoverService). By stating a service type, the importer implies the service type and a domain of discourse for talking about properties of service.<br>
     * If the string representation of the "type" does not obey the rules for service type identifiers, then the P_ILLEGAL_SERVICE_TYPE exception is raised.<br>
     * If the "type" is correct syntactically but is not recognised as a service type within the Framework, then the P_UNKNOWN_SERVICE_TYPE exception is raised.<br>
     * The framework may return a service of a subtype of the "type" requested. A service sub-type can be described by the properties of its supertypes.<br> 
     * 	   @param desiredPropertyList The "desiredPropertyList" parameter is a list of service property {name, mode and value list} tuples that the discovered set of services should satisfy. These properties deal with the non-functional and non-computational aspects of the desired service. The property values in the desired property list must be logically interpreted as "minimum", "maximum", etc. by the framework (due to the absence of a Boolean constraint expression for the specification of the service criterion). It is suggested that, at the time of service registration, each property value be specified as an appropriate range of values, so that desired property values can specify an "enclosing" range of values to help in the selection of desired services.<br>
     * The desiredPropertyList only contains service properties that are relevant for the application. If an application is not interested in the value of a certain service property, this service property shall not be included in the desiredPropertyList.<br>
     * P_INVALID_PROPERTY is raised when an application includes an unknown service property name or invalid service property value.,br>
     *      @param max The "max" parameter states the maximum number of services that are to be returned in the "serviceList" result.
     */
    org.csapi.jr.se.fw.Service[]  discoverService(String serviceTypeName, org.csapi.jr.se.fw.ServiceProperty[] desiredPropertyList, int max)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.IllegalServiceTypeException,org.csapi.jr.se.fw.UnknownServiceTypeException,org.csapi.jr.se.fw.InvalidPropertyException,org.csapi.jr.se.PlatformException;

    /**
     * Returns a list of services so far subscribed by the enterprise operator.<br>
     *  The enterprise operator (or the client applications in the enterprise domain) can obtain a list of subscribed services that they are allowed to access. <br>
     * Returns <serviceList> : The "serviceList" parameter returns a list of subscribed services.  Each service is characterised by its service ID and a list of service properties {name and value list} associated with the service.
     * 
     */
    org.csapi.jr.se.fw.Service[]  listSubscribedServices()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.PlatformException;


} // ServiceDiscovery

