//Source file: FaultManager.java
//Date: July 2003
//Framework to Application Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_application.integrity;

/**
 * This interface is used by the application to inform the framework of events that affect the integrity of the framework and services, and to request information about the integrity of the system.  The fault manager operations do not exchange callback interfaces as it is assumed that the client application supplies its Fault Management callback interface at the time it obtains the Framework's Fault Management interface, by use of the obtainInterfaceWithCallback operation on the IpAccess interface.																								If the IpFaultManager interface is implemented by a Framework, at least one of these methods shall be implemented.  If the Framework is capable of invoking the IpAppFaultManager.appActivityTestReq() method, it shall implement appActivityTestRes() and appActivityTestErr() in this interface.  If the Framework is capable of invoking IpAppFaultManager.genFaultStatsRecordReq(), it shall implement genFaultStatsRecordRes() and genFaultStatsRecordErr() in this interface.
 *
 * 
 */
public interface FaultManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The application invokes this method to test that the framework or its instance of a service is operational. On receipt of this request, the framework must carry out a test on itself or on the client's instance of the specified service, to check that it is operating correctly.  The framework reports the test result by invoking the activityTestRes method on the IpAppFaultManager interface.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
For security reasons the client application has access to the service ID rather than the service instance ID. However, as there is a one to one relationship between the client application and a service, i.e. there is only one service instance of the specified service per client application, it is the obligation of the framework to determine the service instance ID from the service ID.
     *     @param activityTestID The identifier provided by the client application to correlate the response (when it arrives) with this request.
    @param svcID Identifies either the framework or a service for testing. The framework is designated by an empty string.

     */
    void  activityTestReq(int activityTestID, String svcID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to return the result of a framework-requested activity test.
     *     @param activityTestID Used by the framework to correlate this response (when it arrives) with the original request.
    @param activityTestResult The result of the activity test.

     */
    void  appActivityTestRes(int activityTestID, String activityTestResult)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidActivityTestIdException,org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the client application to inform the framework that it can no longer use its instance of the indicated service (either due to a failure in the client application or in the service instance itself). On receipt of this request, the framework should take the appropriate corrective action. 
     *     @param serviceID Identifies the service that the application can no longer use.

     */
    void  svcUnavailableInd(String serviceID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the application to solicit fault statistics from the framework. On receipt of this request the framework must produce a fault statistics record, for either the framework or for the client's instances of the specified services during the specified time interval, which is returned to the client application using the genFaultStatsRecordRes operation on the IpAppFaultManager interface.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     *     @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the framework.
    @param serviceIDs Specifies either the framework or services to be included in the general fault statistics record.  If this parameter is not an empty list, the fault statistics records of the client's instances of the specified services are returned, otherwise the fault statistics record of the framework is returned.

     */
    void  genFaultStatsRecordReq(org.csapi.jr.se.TimeInterval timePeriod, String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to indicate that an error occurred during a framework-requested activity test.
     *     @param activityTestID Used by the framework to correlate this response (when it arrives) with the original request.

     */
    void  appActivityTestErr(int activityTestID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidActivityTestIdException,org.csapi.jr.se.PlatformException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method.  Applications can indicate they no longer use a particular service instance using IpServiceAgreementManagement.terminateServiceAgreement().  Applications can indicate a fault with a particular service instance using IpFaultManager.svcUnavailableInd().
This method is used by the application to inform the framework that it is ceasing its use of the service instance. This may a result of the application detecting a failure.  The framework assumes that the session between this client application and service instance is to be closed and updates its own records appropriately as well as attempting to inform the service instance and/or its administrator.
     *     @param serviceID Identifies the affected application.

     */
    void  appUnavailableInd(String serviceID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the client application to provide fault statistics to the framework in response to a genFaultStatsRecordReq method invocation on the IpAppFaultManager interface. 
     *     @param faultStatistics The fault statistics record.

     */
    void  genFaultStatsRecordRes(org.csapi.jr.se.fw.FaultStatsRecord faultStatistics)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;

    /**
     * This method is used by the client application to indicate an error fulfilling the request to provide fault statistics, in response to a genFaultStatsRecordReq method invocation on the IpAppFaultManager interface. 
     *     @param faultStatisticsError The fault statistics error.

     */
    void  genFaultStatsRecordErr(org.csapi.jr.se.fw.FaultStatisticsError faultStatisticsError)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;



} // FaultManager

