//Source file: LoadManager.java
//Date: July 2003
//Framework to Application Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_application.integrity;

/**
 * The framework API should allow the load to be distributed across multiple machines and across multiple component processes, according to a load management policy. The separation of the load management mechanism and load management policy ensures the flexibility of the load management services. The load management policy identifies what load management rules the framework should follow for the specific client application. It might specify what action the framework should take as the congestion level changes. For example, some real-time critical applications will want to make sure continuous service is maintained, below a given congestion level, at all costs, whereas other services will be satisfied with disconnecting and trying again later if the congestion level rises. Clearly, the load management policy is related to the QoS level to which the application is subscribed.  The framework load management function is represented by the IpLoadManager interface.  Most methods are asynchronous, in that they do not lock a thread into waiting whilst a transaction performs.  To handle responses and reports, the client application developer must implement the IpAppLoadManager interface to provide the callback mechanism.  The application supplies the identity of this callback interface at the time it obtains the framework's load manager interface, by use of the obtainInterfaceWithCallback operation on the IpAccess interface.
 *
 * 
 * 
 */
public interface LoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The client application uses this method to report its current load level (0,1, or 2) to the framework: e.g. when the load level on the application has changed. 
At level 0 load, the application is performing within its load specifications (i.e. it is not congested or overloaded). At level 1 load, the application is overloaded.  At level 2 load, the application is severely overloaded.  In addition this method shall be called by the application in order to report current load status, when load notifications are first requested, or resumed after suspension.
     *     @param loadLevel Specifies the application's load level.

     */
    void  reportLoad(org.csapi.jr.se.fw.LoadLevel loadLevel)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to provide load statistic records for the framework or for its instances of the individual services.   If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     *     @param serviceIDs Specifies the framework or the services for which load statistics records should be reported. If this parameter is not an empty list, the load statistics records of the client's instances of the specified services are returned, otherwise the load statistics record of the framework is returned.
    @param timeInterval Specifies the time interval for which load statistics records should be reported.

     */
    void  queryLoadReq(String[] serviceIDs, org.csapi.jr.se.TimeInterval timeInterval)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.fw.ServiceNotEnabledException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to send load statistic records back to the framework that requested the information; i.e. in response to an invocation of the queryAppLoadReq method on the IpAppLoadManager interface.
     *     @param loadStatistics Specifies the application-supplied load statistics.

     */
    void  queryAppLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to return an error response to the framework that requested the application's load statistics information, when the application is unsuccessful in obtaining any load statistic records; i.e. in response to an invocation of the queryAppLoadReq method on the IpAppLoadManager interface.
     *     @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the application's load statistics.

     */
    void  queryAppLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to register to receive notifications of load level changes associated with either the framework or with its instances of the individual services used by the application.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.  Upon receipt of this method the framework shall inform the client application of the current framework or service instance load using the loadLevelNotification method on the corresponding IpAppLoadManager.
     *     @param serviceIDs Specifies the framework or SCFs to be registered for load control.  To register for framework load control, the serviceIDs parameter must be an empty list.

     */
    void  createLoadLevelNotification(String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to unregister for notifications of load level changes associated with either the framework or with its instances of the individual services used by the application.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     *     @param serviceIDs Specifies the framework or the services for which load level changes should no longer be reported. To unregister for framework load control, the serviceIDs parameter must be an empty list.

     */
    void  destroyLoadLevelNotification(String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to resume sending it load management notifications associated with either the framework or with its instances of the individual services used by the application; e.g. after a period of suspension during which the application handled a temporary overload condition.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.  Upon receipt of this method the framework shall inform the client application of the current framework or service instance load using the loadLevelNotification method on the corresponding IpAppLoadManager.
     *     @param serviceIDs Specifies the framework or the services for which the sending of notifications of load level changes by the framework should be resumed. To resume notifications for the framework, the serviceIDs parameter must be an empty list.

     */
    void  resumeNotification(String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.fw.ServiceNotEnabledException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;

    /**
     * The client application uses this method to request the framework to suspend sending it load management notifications associated with either the framework or with its instances of the individual services used by the application; e.g. while the application handles a temporary overload condition.  If the application does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID.
     *     @param serviceIDs Specifies the framework or the services for which the sending of notifications by the framework should be suspended. To suspend notifications for the framework, the serviceIDs parameter must be an empty list.

     */
    void  suspendNotification(String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.fw.ServiceNotEnabledException,org.csapi.jr.se.UnauthorisedParameterValueException,org.csapi.jr.se.PlatformException;


} // LoadManager

