//Source file: ClientAppInfoQuery.java
//Date: July 2003
//Framework to Enterprise Operator Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * This interface is used by the enterprise operator to list the client applications and the SAGs in its domain and to obtain information about them.
 *
 * 
 * 
 */
public interface ClientAppInfoQuery extends org.csapi.jr.se.CsapiInterface{

    /**
     * Query information about the specified client application of the enterprise operator.
Returns <clientAppDescription> : The "clientAppDescription" parameter contains the clientApp description.
     *     @param clientAppID The "clientAppID" parameter identifies the clientApp object whose description is requested.

     */
    org.csapi.jr.se.fw.ClientAppDescription  describeClientApp(String clientAppID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidClientAppIdException;

    /**
     * Get a list of all client applications belonging to an enterprise operator.
Returns <clientAppIDs> : The "clientAppIDs" parameter identifies the list of client applications in the enterprise operator domain.
     * 
     */
    String[]  listClientApps()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException;

    /**
     * Query information about the specified SAG associated with the enterprise operator.
Returns <SagDescription> : The "sagDescription" parameter returns the SAG-specific description.
     *     @param sagID The "sagID" parameter identifies the SAG whose description is required.

     */
    String  describeSAG(String sagID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Get a list of all SAGs associated with an enterprise operator.
Returns <SagIDList> : The "sagIDList" parameter returns the list of the identifiers of the SAGs associated with the enterprise operator.
     * 
     */
    String[]  listSAGs()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException;

    /**
     * Get a list of all client applications associated with the specified SAG.
Returns <clientAppIDList> : The "clientAppIDList" parameter returns the list of the client applications associated with the SAG.
     *     @param sagID The "sagID" parameter identifies the SAG whose clientAppID list is required.

     */
    String[]  listSAGMembers(String sagID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidSagIdException;

    /**
     * Obtain a list of the SAGs of which the specified client application is a member. 
Returns <sags> : The SAGs of which the client application is a member.
     *     @param clientAppID The "clientAppID" parameter identifies the clientApp object whose membership details are requested.

     */
    String[]  listClientAppMembership(String clientAppID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidClientAppIdException;


} // ClientAppInfoQuery

