//Source file: ServiceProfileInfoQuery.java
//Date: July 2003
//Framework to Enterprise Operator Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * This interface is used by the enterprise operator to obtain information about individual Service Profiles, to find out which SAGs are assigned to a given Service Profile, and to find out what Service Profile is associated with a given client application or SAG.
 *
 * 
 * 
 */
public interface ServiceProfileInfoQuery extends org.csapi.jr.se.CsapiInterface{

    /**
     * Get a list of all service profiles created by the enterprise operator.
Returns <serviceProfileIDList> : The "serviceProfileIDList" is a list of the service profiles associated with the enterprise operator.
     * 
     */
    String[]  listServiceProfiles()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.PlatformException;

    /**
     * Query information about a single service profile.
Returns <serviceProfileDescription> : The "serviceProfileDescription" parameter is a structured data type which contains a description for the specified service profile.
     *     @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile whose description is being requested.

     */
    org.csapi.jr.se.fw.ServiceProfileDescription  describeServiceProfile(String serviceProfileID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;

    /**
     * Get a list of SAGs assigned to the specified service profile. 
Returns <sagIDList> : The "sagIDs" parameter is the list of the SAG IDs that are assigned to the specified service profile.
     *     @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile.  If the serviceProfileID is not recognised by the framework, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.

     */
    String[]  listAssignedMembers(String serviceProfileID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;


} // ServiceProfileInfoQuery

