//Source file: ServiceProfileManagement.java
//Date: July 2003
//Framework to Enterprise Operator Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0

package org.csapi.jr.se.fw.fw_enterprise_operator.service_subscription;

/**
 * This interface is used by the enterprise operator for the management of Service Profiles, which are defined for every subscribed service, and to assign/de - assign the Service Profiles to SAGs.
 *
 * 
 * 
 */
public interface ServiceProfileManagement extends org.csapi.jr.se.CsapiInterface{

    /**
     * Creates a new Service Profile for the specified service contract. The service properties within the service profile restrict the service to meet the client application requirements. A Service Profile is a restriction of the corresponding service contract.  When the description has been verified, a service profile ID will be generated.
Returns <serviceProfileID> : The service profile ID, generated by the framework, will be used to uniquely identify the service profile within the framework.
     *     @param serviceProfileDescription The "serviceProfile" parameter is a structured data type, which contains a subset of the associated service contract information and which may further restrict the value ranges of the service subscription properties.

     */
    String  createServiceProfile(org.csapi.jr.se.fw.ServiceProfileDescription serviceProfileDescription)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;

    /**
     * Modifies the specified Service Profile associated with the enterprise operator.  Only the enterprise operator associated with the particular service profile is allowed to modify it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     *     @param serviceProfile The modified Service Profile.  If the serviceProfileID specified in the serviceProfile parameter does not exist, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.

     */
    void  modifyServiceProfile(org.csapi.jr.se.fw.ServiceProfile serviceProfile)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;

    /**
     * Deletes the specified Service Profile.  Only the enterprise operator associated with the particular service profile is allowed to delete it, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     *     @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile that is to be deleted. If the serviceProfileID does not exist, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.

     */
    void  deleteServiceProfile(String serviceProfileID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;

    /**
     * Assign a Service Profile to the specified SAG.  Only the enterprise operator associated with the serviceProfileID is allowed to assign it to a SAG, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.  Each client application may be assigned to a service only through a single service profile at a particular moment in time. If this condition is violated, a "P_INVALID_SAG_TO_SERVICE_PROFILE_ASSIGNMENT" would be raised. In this case, no partial execution of this method is performed. The enterprise operator can query further information about this invalid assignment using the method requestConflictInfo().
     *     @param sagID The "sagID" parameter identifies the SAG to which Service Profile is to be assigned.  If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" would be raised.
    @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile that is to be assigned to the SAG.  If the serviceProfileID does not exist, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.

     */
    void  assign(String sagID, String serviceProfileID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidSagIdException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.fw.InvalidSagToServiceProfileAssignmentException,org.csapi.jr.se.PlatformException;

    /**
     * De-assign the Service Profile from the specified SAG.  Because only the enterprise operator associated with the serviceProfileID is allowed to deassign it from a SAG, an exception "P_TASK_REFUSED" would be raised if a non-associated enterprise operator invokes this method.
     *     @param sagID The "sagID" parameter identifies the SAG whose Service Profile is to be de-assigned.  If the SAG ID does not exist, an exception "P_INVALID_SAG_ID" would be raised.
    @param serviceProfileID The "serviceProfileID" parameter identifies the Service Profile that is to be de-assigned.  If the serviceProfileID does not exist, an exception "P_INVALID_SERVICE_PROFILE_ID" would be raised.

     */
    void  deassign(String sagID, String serviceProfileID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.fw.InvalidSagIdException,org.csapi.jr.se.fw.InvalidServiceProfileIdException,org.csapi.jr.se.PlatformException;

    /**
     * Requests details about the latest conflict that occurred during performing the method assign() on this interface (i.e. Information about the invocation of assign () that threw a P_INVALID_SAG_TO_SERVICE_PROFILE_ASSIGNMENT). Each client application may be assigned to a service only through a single service profile at a particular moment in time. The enterprise operator could try to assign a SAG to a service profile of a given service. If one or more client applications in this SAG are already assigned to service profiles belonging to the given service, the client applications would have two concurrent service profiles at a particular moment in time. As this is prohibited, a conflict list is generated. 
It is only possible to retrieve information about the last conflicting assign() method call; information about previous conflicts cannot be requested. If there has never been a conflict, the method returns an empty conflict list.
Returns <TpAssignSagToServiceProfileConflictList> : The description of the conflicts occurring at the latest invocation of assign() that raised a P_INVALID_SAG_TO_SERVICE_PROFILE_ASSIGNMENT. Each conflict contains the following elements:
	a. the conflict generating client application.																					b. the SAG and the service profile through which the conflict generating client application is already assigned to the conflict generating service. It includes the current service profile.																c. the conflict generating service.
The conflict generating SAG and service profile are supposed to be well known, because they are input parameters of the assign() method. Therefore, they do not appear in the returned conflict list.
     * 
     */
    org.csapi.jr.se.fw.AssignSagToServiceProfileConflict[]  requestConflictInfo()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.AccessDeniedException,org.csapi.jr.se.PlatformException;


} // ServiceProfileManagement

