//Source file: SvcFaultManager.java
//Date: July 2003
//Framework to Service Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * This interface is used to inform the service instance of events that affect the integrity of the Framework, Service or Client Application.  The Framework will invoke methods on the Fault Management Service Interface that is specified when the service instance obtains the Fault Management Framework interface: i.e. by use of the obtainInterfaceWithCallback operation on the IpAccess interface. 																If the IpSvcFaultManager interface is implemented by a Service, at least one of these methods shall be implemented.  If the Service is capable of invoking the IpFwFaultManager.activityTestReq() method, it shall implement activityTestRes() and activityTestErr() in this interface.  If the Service is capable of invoking IpFwFaultManager.genFaultStatsRecordReq(), it shall implement genFaultStatsRecordRes() and genFaultStatsRecordErr() in this interface.
 *
 * 
 * 
 */
public interface SvcFaultManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The framework uses this method to return the result of a service-requested activity test.
     *     @param activityTestID Used by the service to correlate this response (when it arrives) with the original request.
    @param activityTestResult The result of the activity test.

     */
    void  activityTestRes(int activityTestID, String activityTestResult)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidActivityTestIdException;

    /**
     * The framework invokes this method to test that the service instance is operational. On receipt of this request, the service instance must carry out a test on itself, to check that it is operating correctly.  The service instance reports the test result by invoking the svcActivityTestRes method on the IpFwFaultManager interface.
     *     @param activityTestID The identifier provided by the framework to correlate the response (when it arrives) with this request.

     */
    void  svcActivityTestReq(int activityTestID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework invokes this method to notify the service instance of a failure within the framework. The service instance must not continue to use the framework until it has recovered (as indicated by a fwFaultRecoveryInd).
     *     @param fault Specifies the fault that has been detected by the framework.

     */
    void  fwFaultReportInd(org.csapi.jr.se.fw.InterfaceFault fault)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework invokes this method to notify the service instance that a previously reported fault has been rectified.  The service instance may then resume using the framework.
     *     @param fault Specifies the fault from which the framework has recovered.

     */
    void  fwFaultRecoveryInd(org.csapi.jr.se.fw.InterfaceFault fault)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework invokes this method to inform the service instance that it is no longer available.
     *     @param reason Identifies the reason why the framework is no longer available

     */
    void  fwUnavailableInd(org.csapi.jr.se.fw.FwUnavailReason reason)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework invokes this method to inform the service instance that the client application has reported that it can no longer use the service instance.
     * 
     */
    void  svcUnavailableInd()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * This method is deprecated and will be removed in a later release.  It is strongly recommended not to implement this method. The new method appAvailStatusInd shall be used instead, using the new reason parameter to inform the Service the reason why the Application is unavailable and also when the application becomes available again.
The framework invokes this method to inform the service instance that the framework may have detected that the application has failed: e.g. non-response from an activity test, failure to return heartbeats.
     * 
     */
    void  appUnavailableInd()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * This method is used by the framework to provide fault statistics to a service instance in response to a genFaultStatsRecordReq method invocation on the IpFwFaultManager interface.
     *     @param faultStatistics The fault statistics record.
    @param recordSubject Specifies the entity (framework or application)  whose fault statistics record has been provided.

     */
    void  genFaultStatsRecordRes(org.csapi.jr.se.fw.FaultStatsRecord faultStatistics, org.csapi.jr.se.fw.SubjectType recordSubject)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to indicate that an error occurred during a service-requested activity test. 
     *     @param activityTestID Used by the service instance to correlate this response (when it arrives) with the original request.

     */
    void  activityTestErr(int activityTestID)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidActivityTestIdException;

    /**
     * This method is used by the framework to indicate an error fulfilling the request to provide fault statistics, in response to a genFaultStatsRecordReq method invocation on the IpFwFaultManager interface.
     *     @param faultStatisticsError The fault statistics error.
    @param recordSubject Specifies the entity (framework or application) whose fault statistics record was requested.

     */
    void  genFaultStatsRecordErr(org.csapi.jr.se.fw.FaultStatisticsError faultStatisticsError, org.csapi.jr.se.fw.SubjectType recordSubject)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * This method is deprecated and will be removed in a later release.  It cannot be used as described, since the serviceIDs parameter has no meaning.  It is replaced with generateFaultStatsRecordReq().
This method is used by the framework to solicit fault statistics from the service, for example when the framework was asked for these statistics by the client application using the genFaultStatsRecordReq operation on the IpFaultManager interface. On receipt of this request the service must produce a fault statistics record, for either the framework or for the client's instances of the specified services during the specified time interval, which is returned to the framework using the genFaultStatsRecordRes operation on the IpFwFaultManager interface.  If the framework does not have access to a service instance with the specified serviceID, the P_UNAUTHORISED_PARAMETER_VALUE exception shall be thrown.  The extraInformation field of the exception shall contain the corresponding serviceID. 
     *     @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the service.
    @param serviceIDs Specifies the services to be included in the general fault statistics record.  This parameter is not allowed to be an empty list.

     */
    void  genFaultStatsRecordReq(org.csapi.jr.se.TimeInterval timePeriod, String[] serviceIDs)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException,org.csapi.jr.se.fw.InvalidServiceIdException,org.csapi.jr.se.UnauthorisedParameterValueException;

    /**
     * This method is used by the framework to solicit fault statistics from the service instance, for example when the framework was asked for these statistics by the client application using the genFaultStatsRecordReq operation on the IpFaultManager interface. On receipt of this request the service instance must produce a fault statistics record during the specified time interval, which is returned to the framework using the genFaultStatsRecordRes operation on the IpFwFaultManager interface.  
     *     @param timePeriod The period over which the fault statistics are to be generated. Supplying both a start time and stop time as empty strings leaves the time period to the discretion of the service.

     */
    void  generateFaultStatsRecordReq(org.csapi.jr.se.TimeInterval timePeriod)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;



} // SvcFaultManager

