//Source file: SvcLoadManager.java
//Date: July 2003
//Framework to Service Interfaces for ETSI ES 202 915-03 v.1.1.1, Parlay 4.0, 3GPP TS 29.198-03 v5.1.0

package org.csapi.jr.se.fw.fw_service.integrity;

/**
 * The service developer supplies the load manager service interface to handle requests, reports and other responses from the framework load manager function.  The service instance supplies the identity of its callback interface at the time it obtains the framework's load manager interface, by use of the obtainInterfaceWithCallback() method on the IpAccess interface.																																If the IpSvcLoadManager interface is implemented by a Service, at least one of the methods shall be implemented as a minimum requirement. If load level notifications are supported, then loadLevelNotification() shall be implemented.  If a the Service is capable of invoking the IpFwLoadManager.queryLoadReq() method, then it shall implement queryLoadRes() and queryLoadErr() methods in this interface.
 *
 * 
 * 
 */
public interface SvcLoadManager extends org.csapi.jr.se.CsapiInterface{

    /**
     * The framework uses this method to request the service instance to provide its load statistic records.
     *     @param timeInterval Specifies the time interval for which load statistic records should be reported.

     */
    void  querySvcLoadReq(org.csapi.jr.se.TimeInterval timeInterval)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to send load statistic records back to the service instance that requested the information; i.e. in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface.
     *     @param loadStatistics Specifies the framework-supplied load statistics

     */
    void  queryLoadRes(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to return an error response to the service that requested the framework's load statistics information, when the framework is unsuccessful in obtaining any load statistic records; i.e. in response to an invocation of the queryLoadReq method on the IpFwLoadManager interface.
     *     @param loadStatisticsError Specifies the error code associated with the failed attempt to retrieve the framework's load statistics.

     */
    void  queryLoadErr(org.csapi.jr.se.fw.LoadStatisticError loadStatisticsError)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * Upon detecting load condition change, (e.g. load level changing from 0 to 1, 0 to 2, 1 to 0, for the application or framework which has been registered for load level notifications) this method is invoked on the SCF.  In addition this method shall be invoked on the SCF in order to provide a notification of current load status, when load notifications are first requested, or resumed after suspension.
     *     @param loadStatistics Specifies the framework-supplied load statistics, which include the load level change(s).

     */
    void  loadLevelNotification(org.csapi.jr.se.fw.LoadStatistic[] loadStatistics)throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to request the service instance to suspend sending it any notifications: e.g. while the framework handles a temporary overload condition.
     * 
     */
    void  suspendNotification()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to request the service instance to resume sending it notifications: e.g. after a period of suspension during which the framework handled a temporary overload condition.  Upon receipt of this method the service instance shall inform the framework of the current load using the reportLoad method on the corresponding IpFwLoadManager.
     * 
     */
    void  resumeNotification()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to register to receive notifications of load level changes associated with the  service instance.  Upon receipt of this method the service instance shall inform the framework of the current load using the reportLoad method on the corresponding IpFwLoadManager.
     * 
     */
    void  createLoadLevelNotification()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;

    /**
     * The framework uses this method to unregister for notifications of load level changes associated with the service instance.
     * 
     */
    void  destroyLoadLevelNotification()throws org.csapi.jr.se.MethodNotSupportedException,org.csapi.jr.se.NoCallbackAddressSetException, org.csapi.jr.se.ResourcesUnavailableException, org.csapi.jr.se.TaskCancelledException, org.csapi.jr.se.TaskRefusedException, org.csapi.jr.se.InvalidStateException;


} // SvcLoadManager

